TransFInteraction
=================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: TransFInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TransFInteraction.func

   .. rubric:: Methods Documentation

   .. automethod:: func
